{% load colour_table_row %} {% load naturaltime from humanize %}

### Job History

Job Number | Status | Last Updated | Submitted By
--- | --- | --- | ---
{% for job in history %}
{% if job.run_version != run.run_version %} {% else %} {{ job.title }} {% endif %} | {{ job.status.value_verbose }} | {{ job.last_updated|naturaltime }} | {% if started_by %} {{ started_by }} {% else %} Unknown {% endif %}
{% endfor %}